@@ -1,4 +1,6 @@
 extern crate clap;
+use std::process;
+
 use clap::{Arg, App};
 
 extern crate serde;
@@ -11,6 +13,11 @@ mod inbox_file;
 
 const VERSION: &'static str = env!("CARGO_PKG_VERSION");
 
+fn fatal(message: &str) {
+    println!("{}", message);
+    process::exit(1);
+}
+
 fn main() {
     let matches = App::new("foam-up")
                           .version(VERSION)
@@ -21,14 +28,22 @@ fn main() {
                                .long("path")
                                .value_name("PATH")
                                .help("Sets a custom path")
-                               .takes_value(true))
+                               .takes_value(true)
+                               .required(true))
                           .get_matches();
-
-    // Gets a value for config if supplied by user, or defaults to "default.conf"
-    let path = matches.value_of("path").unwrap_or(".");
-    println!("Value for path: {}", path);
-
+    println!("Developing tools for thought.");
+    let path = matches.value_of("path").expect("Expected a Path");
+    println!("Generating project at {}", path);
     let project = project::Project::new(path);
-    project.create_directories().expect("FATAL: Could not create project directory");
-    project.create_files().expect("FATAL: Could not create project files");
+
+    match project.is_dirty() {
+        Some(project::Error::DirectoryExists) => {
+            fatal("Cannot create project -- Directory already exists");
+        }
+        None => {
+            project.create_directories().expect("FATAL: Could not create project directory");
+            project.create_files().expect("FATAL: Could not create project files");
+            println!("[x] Project created.");
+        }
+    }
 }
\ No newline at end of file
